@@ -20,7 +20,7 @@
 #ifndef AOAUDIO_H
 #define AOAUDIO_H
 
-#include "sample.h"
+#include "sample_info.h"
 
 void ao_audio_close_device();
 int ao_audio_open_device(SampleInfo *);
