@@ -19,8 +19,11 @@
 #ifndef OVERWRITEDIALOG_H
 #define OVERWRITEDIALOG_H
 
-#include "wavbreaker.h"
+#include <gtk/gtk.h>
 
-void overwritedialog_show(GtkWidget *, WriteInfo *);
+#include "sample.h"
+
+enum OverwriteDecision
+overwritedialog_show(GtkWidget *main_window, const char *filename);
 
 #endif /* OVERWRITEDIALOG_H */
