@@ -19,10 +19,15 @@
 #ifndef TOC_H
 #define TOC_H
 
-#include <gtk/gtk.h>
+#include <glib.h>
 
-int toc_read_file(const char *toc_filename, GList *breaks);
-int toc_write_file(const char *toc_filename, const char *wav_filename, GList *breaks);
+#include "track_break.h"
+
+gboolean
+toc_read_file(const char *toc_filename, TrackBreakList *list);
+
+gboolean
+toc_write_file(const char *toc_filename, const char *wav_filename, TrackBreakList *list);
 
 #endif /* TOC_H */
 
