@@ -20,44 +20,15 @@
 #ifndef WAVBREAKER_H
 #define WAVBREAKER_H
 
+#include "track_break.h"
+
 #include <gtk/gtk.h>
 
-typedef struct TrackBreak_ TrackBreak;
-struct TrackBreak_ {
-	gboolean  write;
-	gulong    offset;
-	gchar     *filename;
-	gchar     time[128];
-	gchar     duration[128];
-	gboolean  editable;
-};
-
 void wavbreaker_autosplit(long x);
-void track_break_rename();
 void wavbreaker_write_files(char *dirname);
 GtkWidget *wavbreaker_get_main_window();
-void track_break_add_offset(char *filename, gulong offset);
-void track_break_clear_list();
 void wavbreaker_update_moodbar_state();
+void wavbreaker_update_listmodel();
 void wavbreaker_quit();
 
-guint msf_time_to_offset( gchar *str );
-
-extern char *sample_filename;
-
-enum {
-    CHECK_ALL = 0,
-    CHECK_NONE,
-    CHECK_INVERT
-};
-
-/**
- * When the play marker reaches (x-1)/x (where x is the
- * value of PLAY_MARKER_SCROLL), scroll the waveform so
- * that the play marker continues at position 1/x.
- *
- * i.e. play marker at 7/8 of width -> go to 1/8 of width
- **/
-#define PLAY_MARKER_SCROLL 8
-
 #endif /* WAVBREAKER_H */
