@@ -18,29 +18,31 @@
  */
 
 #include <stdio.h>
-#include <string.h>
-#include <libgen.h>
-#include "wav.h"
-#include "sample.h"
 
-int main(int argc, char *argv[])
+#include "format.h"
+
+int cmd_wavinfo(int argc, char *argv[])
 {
-    int i;
-
-    if( argc < 2) {
-        printf( "Usage: %s [file1.wav] [...]\n", basename( argv[0]));
+    if (argc < 2) {
+        printf("Usage: %s [file1.wav] [...]\n", argv[0]);
         return 1;
     }
 
-    for( i = 1; i < argc; i++) {
-        SampleInfo sampleInfo;
+    format_init();
 
-        printf( "Header info for: %s\n", argv[i]);
+    for (int i = 1; i < argc; i++) {
+        char *error_message = NULL;
+        OpenedAudioFile *oaf = format_open_file(argv[i], &error_message);
 
-        if( wav_read_header( argv[i], &sampleInfo, 1) != 0) {
-            printf("%s", wav_get_error_message());
+        if (oaf == NULL) {
+            printf("Error opening %s: %s\n", argv[i], error_message);
+            g_free(error_message);
+            continue;
         }
 
+        format_print_file_info(oaf);
+        format_close_file(oaf);
+
         printf("\n");
     }
 
