@@ -22,15 +22,18 @@
 #include <string.h>
 #include <sys/stat.h>
 
-#include "sample.h"
-#include "wav.h"
+#include "sample_info.h"
+#include "format_wav.h"
 
-void usage() {
+static void
+usage()
+{
     printf("Must pass filenames of wave files to merge.\n");
     printf("Usage: wavmerge [-o outfile] mergefiles...\n");
 }
 
-int main(int argc, char *argv[])
+int
+cmd_wavmerge(int argc, char *argv[])
 {
     int ret;
     char *merge_filename;
@@ -60,7 +63,7 @@ int main(int argc, char *argv[])
         return 2;
     }
 
-    ret = wav_merge_files(merge_filename, num_files, filenames, DEFAULT_BUF_SIZE, NULL);
+    ret = wav_merge_files(merge_filename, num_files, filenames, NULL);
 
     if (ret != 0) {
         fprintf(stderr,
@@ -76,4 +79,3 @@ int main(int argc, char *argv[])
 
     return 0;
 }
-
